;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
;; loading TwinLisp files
(cl:let* ((hPath (tl-home-path)) (dSep (tl-dir-sep))) ; TL's core methods, funcs, etc.
 (cl:require (concatenate 'string hPath "core" dSep "OtherMacs")) (cl:require (concatenate 'string hPath "core" dSep "ContainerTypesAndMacs")) (cl:require (concatenate 'string hPath "core" dSep "OperMacs")) (cl:require (concatenate 'string hPath "core" dSep "OtherFuncs")) (cl:require (concatenate 'string hPath "core" dSep "OperMeths")) (cl:require (concatenate 'string hPath "core" dSep "OtherMeths")) (cl:require (concatenate 'string hPath "core" dSep "ContainerMeths")) ; TL's translator
 (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslConst")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslStringReading")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslElemSearchFuncs")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslFormBuilding")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "TranslFormWritting")) ; TL's loading func
 (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "LoaderMacs")) ; Other useful functions that can now be defined using working TL
 (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "omop")) (cl:require (_+_ (_+_ (_+_ hPath "core") dSep) "OtherMeths2")))
